/*****************************************************************************
 * Apci33w.h
 *
 * aPCI-P33
 * Copyright (C) ADTEK SYSTEM SCIENCE Co.,Ltd.
 *****************************************************************************/
#pragma once

#include <windows.h>

using namespace System;
using namespace System::ComponentModel;
using namespace System::Collections;
using namespace System::Windows::Forms;
using namespace System::Data;
using namespace System::Drawing;
using namespace System::Threading;
using namespace System::Runtime::InteropServices;

#ifdef MessageBox
#undef MessageBox
#endif

// NX̐錾
__gc public class Apci33w;

__gc public class Apci33w
{
private:
	static int mErrWradll = SUCCESS;	// bp[֐G[

public:
	/*==================*/
	/*	Error Code		*/
	/*==================*/
	static const int	SUCCESS					= 0;	/* Successfully proccessed */
	static const int	ERR_SYSTEM				= 1;	/* Call GetLastError() */
	static const int	ERR_NO_DEVICE			= 2;	/* No card */
	static const int	ERR_IN_USE				= 3;	/* Device is in use */
	static const int	ERR_INVALID_SLOT		= 4;	/* Invalid slot number */
	static const int	ERR_RESOURCE			= 5;	/* Resource exhaustion */
	static const int	ERR_INVALID_PORT		= 6;	/* Invalid port */
	static const int	ERR_INVALID_ARGUMENT	= 7;	/* Invalid argument */
	static const int	ERR_NO_CREATE			= 8;	/* No created device */
	static const int	ERR_WRAPDLL				= -1;	// bp[֐G[

	/*==========================================*/
	/*	aPCI-P33 card's relative port address	*/
	/*==========================================*/
	static const int	PORT_1					= 0;
	static const int	PORT_2					= 1;
	static const int	PORT_3					= 2;
	static const int	PORT_4					= 3;
	static const int	PORT_5					= 4;
	static const int	PORT_6					= 5;
	static const int	PORT_7					= 6;
	static const int	PORT_8					= 7;

	/*==================*/
	/*	Miscellaneous	*/
	/*==================*/
	static const int	MAX_SLOTS				= 16;	/* Maximum number of slots */
	static const int	MAX_PORTS				= 4;	/* Maximum number of user ports */

	static const short	SLOT_AUTO				= -1;	/* default search */

	/*==================================*/
	/*	Resource infomation structure	*/
	/*==================================*/
	static const int	MAX_MEM					= 9;
	static const int	MAX_IO					= 20;
	static const int	MAX_IRQ					= 7;
	static const int	MAX_DMA					= 7;
	static const int	MAX_RSV					= 3;

	[StructLayout(LayoutKind::Sequential)]
	__gc class Resource
	{
	public:
		Int32 dwNumMemWindows;
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_MEM)]
		Int32 dwMemBase[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_MEM)]
		Int32 dwMemLength[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_MEM)]
		Int32 dwMemAttrib[];
		Int32 dwNumIOPorts;
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_IO)]
		Int32 dwIOPortBase[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_IO)]
		Int32 dwIOPortLength[];
		Int32 dwNumIRQs;
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_IRQ)]
		Int32 dwIRQRegisters[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_IRQ)]
		Int32 dwIRQAttrib[];
		Int32 dwNumDMAs;
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_DMA)]
		Int32 dwDMALst[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_DMA)]
		Int32 dwDMAAttrib[];
		[MarshalAs(UnmanagedType::ByValArray, SizeConst=Apci33w::MAX_RSV)]
		Int32 dwReserved1[];
	};

	/*==================*/
	/*	API Functions	*/
	/*==================*/
	[DllImport("apci33.dll")]
	static bool Apci33GetVersion( int* pdwDllVersion, int* pdwDriverVersion );
	[DllImport("apci33.dll")]
	static bool Apci33Create( short* pwLogSlot );
	[DllImport("apci33.dll")]
	static bool Apci33Close( short wLogSlot );
	[DllImport("apci33.dll")]
	static bool Apci33GetResource( short wLogSlot, [In][Out] Resource* pres );
	[DllImport("apci33.dll")]
	static bool Apci33GetSwitchValue( short wLogSlot, int* pdwSwitchValue );
	[DllImport("apci33.dll")]
	static bool Apci33OutPort( short wLogSlot, int dwLogPort, Byte bOutValue );
	[DllImport("apci33.dll")]
	static bool Apci33GetLastError( short wLogSlot );

	/*============================================================================
	// 	  aPCI-P33 DLL,޲ײްްޮݔԍ擾
	// 	  pdwDllVersion		DLLްޮݔԍi[̈ւ߲
	//		  pdwDriverVersion	޲ײްްޮݔԍi[̈ւ߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetVersion(int* pdwDllVersion, int* pdwDriverVersion)
	{
		try {
			return Apci33GetVersion(pdwDllVersion, pdwDriverVersion);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P33̔Cӂ޲̎gp錾
	// 	  pwLogSlot	 gp޲̘_ۯĔԍi[߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool Create(short* pwLogSlot)
	{
		try {
			return Apci33Create(pwLogSlot);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P33̔Cӂ޲̎gpJ
	// 	  wLogSlot ޲̘_ۯĔԍ
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool Close(short wLogSlot)
	{
		try {
			return Apci33Close(wLogSlot);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  w޲ؿ擾
	// 	  wLogSlot	ؿ擾޲̘_ۯĔԍ
	//		  pResInfo	ؿi[\߲̂
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetResource(short wLogSlot, [In][Out] Resource* pResInfo)
	{
		try {
			return Apci33GetResource(wLogSlot, pResInfo);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  Cӂ߰Ăްo
	// 	  wLogSlot	o͂޲̘_ۯĔԍ
	//		  dwLogPort	o͂_߰
	//		  bOutValue o͂ް
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool OutPort(short wLogSlot, int dwLogPort, Byte bOutValue)
	{
		try {
			return Apci33OutPort(wLogSlot, dwLogPort, bOutValue);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P33̴װ
	// 	  wLogSlot	װ޲̘_ۯĔԍ
	// ߂l װ
	//==========================================================================*/
	static int GetLastError(short wLogSlot)
	{
		try {
			if (mErrWradll == ERR_WRAPDLL) {	// bp[֐G[Ȃ
				mErrWradll = SUCCESS;			// NA
				return ERR_WRAPDLL;
			} else {
				return Apci33GetLastError(wLogSlot);
			}
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = SUCCESS;	// bp[֐G[
			return ERR_WRAPDLL;
		}
	}
	/*============================================================================
	// 	  ۰ذ̒l擾
	//    wLogSlot			۰ذ̒l擾޲̘_ۯĔԍ
	// 		  pdwSwitchValue	۰ذ̒li[̈ւ߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetSwitchValue(short wLogSlot, int* pdwSwitchValue)
	{
		try {
			return Apci33GetSwitchValue(wLogSlot, pdwSwitchValue);
		}
		catch (Exception __gc * e) {
			MessageBox::Show(e->Message, S"aPCI-P33 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

};
