/************************************************************************/
/*		aPCI-P33 Device Driver for Windows 9x/NT						*/
/*																		*/
/*			apci33.h	-	Win32 interface definition					*/
/*			date		-	1999/06/02									*/
/************************************************************************/

#if !defined( APCI33_H )
#define	APCI33_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI33_SUCCESS				0	/* Successfully proccessed */
#define	APCI33_ERR_SYSTEM			1	/* Call GetLastError() */
#define	APCI33_ERR_NO_DEVICE		2	/* No card */
#define	APCI33_ERR_IN_USE			3	/* Device is in use */
#define	APCI33_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI33_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI33_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI33_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI33_ERR_NO_CREATE		8	/* No created device */
#define APCI33_ERR_BAD_COMMAND		9	/* Bad command */
#define	APCI33_ERR_INVALID_MODE		10	/* Invalid mode */

/*==========================================*/
/*	aPCI-P33 card's relative port address	*/
/*==========================================*/
#define	APCI33_PORT_1		0
#define	APCI33_PORT_2		1
#define	APCI33_PORT_3		2
#define	APCI33_PORT_4		3
#define	APCI33_PORT_5		4
#define	APCI33_PORT_6		5
#define	APCI33_PORT_7		6
#define	APCI33_PORT_8		7

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI33_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI33_MAX_PORTS	8			/* Maximum number of user ports */

										/* default search */
#define	APCI33_SLOT_AUTO	( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI33_BOARD_ID		0x9133		/* pci bus device id */
#define	APCI33_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI33_DEVICE_ID	( ( DWORD )APCI33_BOARD_ID\
							| ( ( DWORD )APCI33_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI33_MAX_MEM	9			/* number of memory windows */
#define	APCI33_MAX_IO	20			/* number of i/o windows */
#define	APCI33_MAX_DMA	7			/* number of dmas */

typedef	struct	_APCI33RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI33_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI33_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI33_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI33_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI33_MAX_IO];	/* I/O port length */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI33_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI33_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI33RESOURCE, *PAPCI33R;

#if !defined( APCI33_DRIVER )
#define	APCI33_API

#if !defined( APCI33_DLL )
	#define APCI33LIB_API	extern __declspec( dllimport )
#else
	#define APCI33LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI33LIB_API BOOL		WINAPI	Apci33GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI33LIB_API BOOL		WINAPI	Apci33Create( PWORD pwLogSlot );
APCI33LIB_API BOOL		WINAPI	Apci33Close( WORD wLogSlot );
APCI33LIB_API BOOL		WINAPI	Apci33GetResource( WORD wLogSlot, PAPCI33R pres );
APCI33LIB_API BOOL		WINAPI	Apci33OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI33LIB_API DWORD		WINAPI	Apci33GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI33_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI33_H ) */

/**/